rstan as well as the design matrices and other data for the model.Returns object generated from model fit by bayesGAM
# S4 method for bayesGAMfit
show(object)Object of type bayesGAMfit which stores the results from rstan, design matrices, and other data for the model.
resultsObject of type stanfit returned from calling rstan::sampling
modelObject of custom type glmModel with the data and input parameters passed to rstan
offsetOptionally numeric offset for the generalized additive model
spcontrolList of control parameters for bayesGAMfit
mcmcresMatrix of MCMC results for all chains, if plot data is stored
pdataDataframe for default plot method, if plot data is stored.